# itu

`import this` versi Bahasa Indonesia

[![PyPI version](https://badge.fury.io/py/itu.svg)](https://badge.fury.io/py/itu) ![PyPI - Downloads](https://img.shields.io/pypi/dm/itu)

## Cara Pemasangan

```bash
pip install itu
```

## Cara Penggunaan

```python
import itu
```

## Hasil

```bash
Zen tentang Python, oleh Tim Peters

Yang elok lebih baik daripada yang buruk.
Yang eksplisit lebih baik daripada yang implisit.
Yang sederhana lebih baik daripada yang kompleks.
Yang kompleks lebih baik daripada yang rumit.
Yang merata lebih baik daripada yang bersarang.
Yang renggang lebih baik daripada yang padat.
Kemudahan Pembacaan penting.
Kasus khusus tidak cukup istimewa untuk melanggar aturan.
Walaupun kepraktisan lebih penting daripada kemurnian.
Kesalahan tidak boleh dilewatkan diam-diam.
Kecuali didiamkan dengan gamblang.
Jika dihadapkan dengan hal yang ambigu, tolak lah godaan untuk menebak.
Hanya boleh ada satu -- dan kalau bisa satu saja -- cara yang jelas untuk melakukan sesuatu.
Walaupun bisa saja cara tersebut tidak jelas pada awalnya, kecuali anda orang Belanda.
Sekarang lebih baik daripada tidak pernah sama sekali.
Meskipun tidak pernah sama sekali seringkali lebih baik daripada *sekarang*.
Jika implementasinya sulit dijelaskan, maka gagasan tersebut buruk.
Jika implementasinya mudah dijelaskan, maka gagasan tersebut mungkin saja baik.
"Namespace" adalah ide yang sangat baik sekali -- mari gunakan fitur ini lebih dan lebih lagi!

Diterjemahkan oleh Alex Xandra Albert Sim.
```

## Kontribusi

Silakan berkontribusi dengan membuka _Pull Request_ atau melaporkan jika ada masalah.

## Kredit

- Terjemahan diambil dari [sini](https://bertzzie.com/post/38/zen-dari-python-sebuah-pembahasan) oleh [Alex Xandra Albert  Sim](https://github.com/bertzzie).
- Terinspirasi oleh `import this` dan [`import iki`](https://github.com/ismailsunni/iki)

## Pertanyaan

**Pertanyaan:** Kenapa `itu` dan bukan `ini`?

**Jawaban:** Karena `ini` sudah dipakai oleh package [lain](https://pypi.org/project/INI/)

---

**Pertanyaan:** Kenapa membuat `itu`?

**Jawaban:** Untuk senang-senang saja. Siapa tahu bisa berguna :)
